import { EventEmitter, OnInit, QueryList } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { MatMenuTrigger } from '@angular/material/menu';
import { FilterComponent } from '../filter/filter.component';
import { AppliedFilterModel } from '../models/AppliedFilterModel';
import { FilterModel } from '../models/FilterModel';
import { IEventCard } from '../models/IEventCard';
import { CustomOption } from '../models/IOption';
import { NgxLiveViewService } from '../ngx-live-view.service';
import * as i0 from "@angular/core";
export declare class EventCardComponent implements OnInit {
    private _NgxLiveViewService;
    private dialog;
    queueLimit: number;
    toolbarOptions: CustomOption[];
    filters: FilterModel[];
    properties: any[];
    cardOptions: CustomOption[];
    dblclickEventCard: EventEmitter<any>;
    ClickFunction: EventEmitter<any>;
    filterChild: QueryList<FilterComponent>;
    matMenuTrigger: QueryList<MatMenuTrigger>;
    showFilter: boolean;
    eventCards: IEventCard[];
    isfilterApplied: boolean;
    appliedFilters: AppliedFilterModel[];
    menuTopLeftPosition: {
        x: string;
        y: string;
    };
    constructor(_NgxLiveViewService: NgxLiveViewService, dialog: MatDialog);
    ngOnInit(): void;
    /**
     * It checks if the data passed to it matches the filters applied by the user.
     * @param {IEventCard} data - IEventCard - This is the data that is being filtered.
     */
    checkFilterOnData(data: IEventCard): boolean;
    filterAppliedCallback(data: AppliedFilterModel[]): void;
    /**
     * The function is called when the user clicks on the "Remove Filter" button. It sets the
     * isfilterApplied variable to false.
     */
    removeFilterCallback(): void;
    /**
     * It loops through all the child components and calls the onClear() function on each one.
     */
    removeFilters(): void;
    /**
     * It opens a dialog box and passes the event object to it.
     * @param {IEventCard} event - IEventCard - this is the event object that is being passed to the
     * dialog
     */
    showEventDetails(event: IEventCard): void;
    /**
     * It clears the list of event cards.
     */
    clearList(): void;
    /**
     * Method called when the user click with the right button
     * @param event MouseEvent, it contains the coordinates
     * @param item Our data contained in the row of the table
     */
    onRightClick(event: MouseEvent, item: any): void;
    /**
     * This function takes a string as an argument and passes it to the eventCardCallback function in
     * the NgxLiveViewService service.
     * @param {string} callback - string - The name of the callback function to be called.
     */
    eventCardCallback(callback: any): void;
    /**
     * This function is called when the user clicks user passed function on the event card toolbar functions. It sends a message to the
     * service to tell it to call the callback function that was passed in.
     * @param {any} callback - This is the function that you want to call.
     */
    eventCardToolbarFunctionCallback(callback: any): void;
    /**
     * This function is called when the user clicks on the event card functions. It emits an event to the parent
     * component, which then calls the callback function that was passed in as a parameter.
     * @param {any} callback - This is the function that you want to call.
     * @param {any} event - the event object
     */
    eventCardFunctionCallback(callback: any, event: any): void;
    /**
     * It checks if the eventdata with the filterData, if it does, it returns true, if not, it
     * returns false.
     * @param {string} condition - the condition that you want to check
     * @param {any} eventdata - the data of the event that is being checked
     * @param {any} filterData - The data that is entered in the filter input field.
     * @returns a boolean value.
     */
    checkConditionOnFilter(condition: string, eventdata: any, filterData: any): any;
    /**
     * It checks if the eventdata matches the filterData based on the condition.
     * @param {string} condition - string - the condition to be applied (e.g. 'contains', 'equals', etc.)
     * @param {any} eventdata - The data that is being filtered
     * @param {any} filterData - This is the data that is being filtered.
     * @param {any} filterMatched - This is a class that has a property called value. This is used to keep
     * track of how many filters have been matched.
     */
    applyConditionAsPerType(condition: string, eventdata: any, filterData: any, filterMatched: any): void;
    /**
     * It takes a key and an event, and returns the value of the property with the given key.
     * @param {string} key - the key of the property you want to get the value of
     * @param {IEventCard} event - IEventCard
     * @returns The value of the property with the key that matches the key passed in.
     */
    getPropertyValue(key: string, event: IEventCard): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<EventCardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EventCardComponent, "lib-event-card", never, { "queueLimit": "queueLimit"; "toolbarOptions": "toolbarOptions"; "filters": "filters"; "properties": "properties"; "cardOptions": "cardOptions"; }, { "dblclickEventCard": "dblclickEventCard"; "ClickFunction": "ClickFunction"; }, never, never>;
}
