import { EventEmitter, OnChanges, OnInit, QueryList, SimpleChanges } from '@angular/core';
import { MatMenuTrigger } from '@angular/material/menu';
import { ZTreeModel, treeToolbarButtonModel } from '../models/ITreeModel';
import { NgxLiveViewService } from '../ngx-live-view.service';
import { TreeViewService } from './tree-view.service';
import * as i0 from "@angular/core";
export declare class TreeViewComponent implements OnInit, OnChanges {
    private _treeService;
    private _ngxLiveViewService;
    nodesToBeInserted: any[];
    isDomCreated: boolean;
    search: boolean;
    searchText: string;
    searchWithParam: string;
    currentSelectedNode: any;
    theme: string;
    treeID: string;
    toolbarButtons: treeToolbarButtonModel[];
    NodeUnSelected: EventEmitter<any>;
    NodeSelected: EventEmitter<any>;
    NodeChecked: EventEmitter<any>;
    NodeUnChecked: EventEmitter<any>;
    NodeSingleClick: EventEmitter<any>;
    NodeDoubleClick: EventEmitter<any>;
    ContextmenuClicked: EventEmitter<any>;
    toolbarButtonClicked: EventEmitter<any>;
    EmitEventonNodeExpand: EventEmitter<any>;
    matMenuTrigger: QueryList<MatMenuTrigger>;
    menuTopLeftPosition: {
        x: string;
        y: string;
    };
    constructor(_treeService: TreeViewService, _ngxLiveViewService: NgxLiveViewService);
    onBeforeClick: (treeId: any, treeNode: any) => boolean;
    /**
     * Emits an Event, when a node is selected
     *
     * @param {*} event
     * @param {*} treeID
     * @param {ZTreeModel} targetNode
     * @param {*} moveType
     * @memberof TreeViewComponent
     */
    onNodeSingleClick: (event: any, treeID: any, targetNode: ZTreeModel, moveType: any) => void;
    /**
     * Emits an Event, when a node is double clicked
     *
     * @param {(Event | undefined)} event
     * @param {*} treeId
     * @param {*} treeNode
     * @memberof TreeViewComponent
     */
    onNodeDblClick: (event: Event | undefined, treeId: any, treeNode: any) => void;
    /**
     * It is used to check weather a node is droppable or not
     *
     * @param {*} treeId
     * @param {Array<ZTreeModel>} treeNodes
     * @returns {boolean}
     * @memberof TreeViewComponent
     */
    onNodebeforeDrag: (treeId: any, treeNodes: Array<ZTreeModel>) => boolean;
    /**
     * It is used when a node is dropped, and plays video if it is a video node and dropped on a Grid or do other works
     *
     * @param {{ target: any; originalEvent: { path: any[]; }; }} event
     * @param {*} treeId
     * @param {Array<ZTreeModel>} treeNodes
     * @param {*} targetNode
     * @param {*} moveType
     * @param {*} isCopy
     * @returns {boolean}
     * @memberof TreeViewComponent
     */
    onNodeDrop: (event: {
        target: any;
        originalEvent: any;
    }, treeId: any, treeNodes: Array<ZTreeModel>, targetNode: any, moveType: any, isCopy: any) => void;
    /**
     * Emit event on node checked
     *
     * @param {*} treeId
     * @param {*} treeNodes
     * @param {{ checked: any; }} targetNode
     * @param {*} moveType
     * @memberof TreeViewComponent
     */
    onNodeCheck: (treeId: any, treeNodes: any, targetNode: {
        checked: any;
    }, moveType: any) => void;
    /**
     * Emit event on node right click on any node
     *
     * @param {*} event
     * @param {*} treeId
     * @param {*} node
     * @memberof TreeViewComponent
     */
    onNodeRightClick: (event: any, treeId: any, node: any) => void;
    /**
     * Emit event on node expand
     *
     * @param {*} event
     * @param {*} treeId
     * @param {*} node
     * @memberof TreeViewComponent
     */
    onNodeExpand: (event: any, treeId: any, node: any) => void;
    /**
     * Expand the nodes
     *
     * @param {*} treeId
     * @param {*} treeNode
     * @memberof TreeViewComponent
     */
    onBeforeExpand: (treeId: any, treeNode: any) => void;
    setting: {
        view: {
            dblClickExpand: boolean;
            showLine: boolean;
            showIcon: boolean;
            selectedMulti: boolean;
            addDiyDom: (treeId: any, treeNode: {
                tId: string;
                level: number;
            }) => void;
        };
        edit: {
            drag: {
                prev: boolean;
                next: boolean;
                inner: boolean;
            };
            enable: boolean;
            showRemoveBtn: boolean;
            showRenameBtn: boolean;
        };
        data: {
            key: {
                title: string;
            };
            simpleData: {
                enable: boolean;
                idKey: string;
                pIdKey: string;
                rootPId: string;
            };
        };
        check: {
            enable: boolean;
            chkStyle: string;
            chkboxType: {
                Y: string;
                N: string;
            };
        };
        callback: {
            beforeClick: (treeId: any, treeNode: any) => boolean;
            onClick: (event: any, treeID: any, targetNode: ZTreeModel, moveType: any) => void;
            onCheck: (treeId: any, treeNodes: any, targetNode: {
                checked: any;
            }, moveType: any) => void;
            onRightClick: (event: any, treeId: any, node: any) => void;
            beforeDrag: (treeId: any, treeNodes: Array<ZTreeModel>) => boolean;
            onDrop: (event: {
                target: any;
                originalEvent: any;
            }, treeId: any, treeNodes: Array<ZTreeModel>, targetNode: any, moveType: any, isCopy: any) => void;
            beforeExpand: (treeId: any, treeNode: any) => void;
            onExpand: (event: any, treeId: any, node: any) => void;
            onDblClick: (event: Event | undefined, treeId: any, treeNode: any) => void;
        };
    };
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * It is used to add styling to the tree node
     *
     * @param {*} treeId
     * @param {{ tId: string; level: number; }} treeNode
     * @memberof TreeViewComponent
     */
    addDiyDom(treeId: any, treeNode: {
        tId: string;
        level: number;
    }): void;
    /**
     *It is used to get tree object
     *
     * @return {*}
     * @memberof TreeViewComponent
     */
    getTreeObject(): any;
    /**
     * It is used to insert nodes into tree
     *
     * @param {*} parentNode
     * @param {Array<ZTreeModel>} nodes
     * @memberof TreeViewComponent
     */
    insertNodes(parentNode: any, nodes: Array<ZTreeModel>): void;
    /**
     * It emits a event when toolbar button is clicked
     *
     * @param {*} id
     * @memberof TreeViewComponent
     */
    toolbarButtonClick(id: any): void;
    /**
     * It searches node in tree
     *
     * @memberof TreeViewComponent
     */
    searchNode(): void;
    /**
     * It Clears Search Field
     *
     * @memberof TreeViewComponent
     */
    clearSearchField(): void;
    /**
     * It Removes Search Bar
     *
     * @memberof TreeViewComponent
     */
    RemoveSearchBar(): void;
    filterNodes(): void;
    /**
     * It is used to get the selected nodes
     *
     * @return {*} Tree Nodes
     * @memberof TreeViewComponent
     */
    getSelectedNodes(): any;
    /**
     * It is used to collapse any open single path, if any other path is called to open
     *
     * @param {*} newNode
     * @memberof TreeViewComponent
     */
    singlePath(newNode: any): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TreeViewComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TreeViewComponent, "lib-tree-view", never, { "theme": "theme"; "treeID": "treeID"; "toolbarButtons": "toolbarButtons"; }, { "NodeUnSelected": "NodeUnSelected"; "NodeSelected": "NodeSelected"; "NodeChecked": "NodeChecked"; "NodeUnChecked": "NodeUnChecked"; "NodeSingleClick": "NodeSingleClick"; "NodeDoubleClick": "NodeDoubleClick"; "ContextmenuClicked": "ContextmenuClicked"; "toolbarButtonClicked": "toolbarButtonClicked"; "EmitEventonNodeExpand": "EmitEventonNodeExpand"; }, never, never>;
}
