import { Subject } from 'rxjs';
import { ZTreeModel, ExternalDataForTree } from '../models/ITreeModel';
import * as i0 from "@angular/core";
export declare class TreeViewService {
    constructor();
    nodeDropInGridSubject: Subject<any>;
    /**
     *Create method for creating tree nodes
     *
     * @param {string} id
     * @param {string} name
     * @param {Array<ZTreeModel>} children
     * @param {ExternalDataForTree} data
     * @param {boolean} checked
     * @param {boolean} isParent
     * @param {boolean} nocheck
     * @param {string} [icon]
     * @param {number} [random]
     * @param {string} [title]
     * @param {string} [iconOpen]
     * @param {string} [iconClose]
     * @return {*}
     * @memberof TreeViewService
     */
    createNode(id: string, name: string, children: Array<ZTreeModel>, data: ExternalDataForTree, checked: boolean, isParent: boolean, nocheck: boolean, icon?: string, random?: number, title?: string, iconOpen?: string, iconClose?: string): ZTreeModel;
    /**
     * Used to get Tree Object as per Tree Id
     *
     * @param {*} treeID
     * @return {*}  Tree Node
     * @memberof TreeViewService
     */
    getTreeObject(treeID: any): any;
    /**
     * Used to get Tree Node By Param
     *
     * @private
     * @param {*} treeID
     * @param {string} paramKey
     * @param {string} paramValue
     * @return {*} Tree Node
     * @memberof TreeViewService
     */
    private getTreeNodeByParam;
    /**
     * Used to insert Nodes
     *
     * @param {string} treeID
     * @param {*} parentNode
     * @param {Array<ZTreeModel>} nodes
     * @memberof TreeViewService
     */
    insertNodes(treeID: string, parentNode: any, nodes: Array<ZTreeModel>): void;
    /**
     * Used to get Tree Node By Id
     *
     * @param {*} treeID
     * @param {string} id
     * @return {*}  Tree Node
     * @memberof TreeViewService
     */
    getTreeNodeById(treeID: any, id: string): ZTreeModel;
    /**
     * Used to get Tree Node By Random Id
     *
     * @param {*} treeID
     * @param {string} id
     * @return {*} Tree Node
     * @memberof TreeViewService
     */
    getTreeNodeByRandomId(treeID: any, id: string): ZTreeModel;
    /**
     * Used to get Tree Node By Name
     *
     * @param {*} treeID
     * @param {string} name
     * @return {*} Tree Node
     * @memberof TreeViewService
     */
    getTreeNodeByName(treeID: any, name: string): any;
    /**
     * Used to check if Node is Checked
     *
     * @param {*} treeID
     * @param {ZTreeModel} node
     * @return {*}  {boolean}
     * @memberof TreeViewService
     */
    isNodeChecked(treeID: any, node: ZTreeModel): boolean;
    /**
     * Used to Check Node
     *
     * @param {*} treeID
     * @param {ZTreeModel} node
     * @param {boolean} callback
     * @memberof TreeViewService
     */
    checkNode(treeID: any, node: ZTreeModel, callback: boolean): void;
    /**
     * Used to remove all Child Node
     *
     * @param {*} treeID
     * @param {ZTreeModel} parentNode
     * @memberof TreeViewService
     */
    removeAllChildNodes(treeID: any, parentNode: ZTreeModel): void;
    /**
     * Used to get Selected Node
     *
     * @param {*} treeID
     * @param {ZTreeModel} node
     * @param {boolean} selectOtherNode
     * @memberof TreeViewService
     */
    selectNode(treeID: any, node: ZTreeModel, selectOtherNode: boolean): void;
    /**
     * Used to get Parent Node
     *
     * @param {*} treeID
     * @param {ZTreeModel} node
     * @return {*} Tree Node
     * @memberof TreeViewService
     */
    getParentNode(treeID: any, node: ZTreeModel): any;
    /**
     * Used to Delete Node
     *
     * @param {*} treeID
     * @param {ZTreeModel} node
     * @memberof TreeViewService
     */
    deleteNode(treeID: any, node: ZTreeModel): void;
    /**
     * Used to get First Node
     *
     * @param {*} treeID
     * @return {*} Tree Node
     * @memberof TreeViewService
     */
    getFirstNode(treeID: any): ZTreeModel | null;
    /**
     * Used to update Nodes
     *
     * @param {*} treeID
     * @param {ZTreeModel} node
     * @memberof TreeViewService
     */
    updateNode(treeID: any, node: ZTreeModel): void;
    /**
     * Used to Deselect all Nodes as per Tree ID
     *
     * @param {*} treeID
     * @memberof TreeViewService
     */
    deSelectAllNodes(treeID: any): void;
    /**
     * Used to Deselect any Node as per Tree ID and node
     *
     * @param {*} treeID
     * @param {*} node
     * @memberof TreeViewService
     */
    deSelectNode(treeID: any, node: any): void;
    /**
     * Check If tree is initialized or not as per Tree ID
     *
     * @param {*} treeID
     * @return {*} Boolean
     * @memberof TreeViewService
     */
    isTreeIntilized(treeID: any): boolean;
    /**
     *  To get all nodes of Any Tree ID
     *
     * @param {*} treeID
     * @return {*} Array of {ZTreeModel}
     * @memberof TreeViewService
     */
    getAllNodes(treeID: any): ZTreeModel[];
    /**
     * This function clears the tree by destroying it and then recreating it.
     * @param {any} treeID - The ID of the tree you want to clear.
     */
    clearTree(treeID: any): void;
    /**
     * Get the selected nodes from the tree object.
     * @param {any} treeID - The ID of the tree you want to get the selected nodes from.
     * @returns An array of selected nodes.
     */
    getSelectedNodes(treeID: any): any;
    static ɵfac: i0.ɵɵFactoryDeclaration<TreeViewService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<TreeViewService>;
}
